StderrLock

Struct StderrLock 

1.0.0 · Source
pub struct StderrLock<'a> { /* private fields */ }
A locked reference to the Stderr handle.

This handle implements the Write trait and is constructed via the Stderr::lock method. See its documentation for more.

Note: Windows Portability Considerations

When operating in a console, the Windows implementation of this stream does not support non-UTF-8 byte sequences. Attempting to write bytes that are not valid UTF-8 will return an error.

In a process with a detached console, such as one using #![windows_subsystem = "windows"], or in a child process spawned from such a process, the contained handle will be null. In such cases, the standard library’s Read and Write will do nothing and silently succeed. All other I/O operations, via the standard library or via raw Windows API calls, will fail.